@@ -20,7 +20,7 @@ from treform.utility import *
 from treform.abbreviations import *
 from treform.synonym import *
 from treform.syntactic_parser import *
-#from treform.spelling import *
+from treform.spelling import *
 
 from os import listdir
 from .version import __version__
